---
label: JRCLUST
dockerfile:
environment: MATLAB
wrapper: https://github.com/flatironinstitute/spikeforest/blob/master/spikeforest/spikesorters/jrclust/jrclust.py
notes: 
website: https://github.com/JaneliaSciComp/JRCLUST
source_code: https://github.com/JaneliaSciComp/JRCLUST
authors: James Jun and Alan Liddell
processor_name: JRClust
doi: 10.1101/101030
---

# JRCLUST

## Description

From the website: JRCLUST is a scalable and customizable package for spike sorting on high-density silicon probes. It is written in MATLAB and CUDA. JRCLUST was originally developed by James Jun and is currently maintained by Vidrio Technologies.

## References
[1] Jun, JJ et al., Real-time spike sorting platform for high-density extracellular probes with ground-truth validation and drift correction. bioRxiv, 101030; doi: https://doi.org/10.1101/101030